import config from '../../../config';

export async function runUseCase(UseCase: any, { params }: any): Promise<any> {
    return new UseCase().run(params);
}

export function makeRequestHandler(UseCase: any, mapToParams: Function = (params: any) => params): any {
    function logRequest(params: any, result: any, startTime: number, isLog: boolean = config.log): void {
        // tslint:disable-next-line:no-console
        isLog && console.debug(JSON.stringify({
            useCase: UseCase.name,
            runtime: Date.now() - startTime,
            params,
            result,
        }));
    }

    return async function routerHandler(req: Function, res: Function, next: Function = () => {}): Promise<any> {
        try {
            const startTime: number = Date.now();
            const params: any = mapToParams(req, res);
            const result: any = await runUseCase(UseCase, { params });
            logRequest(params, result, startTime);
        } catch (err) {
            console.error('err', err);
        }
    };
}
