import { Repository } from './Repository';
import { CreateMariaDbConnection } from './createrMariaDbConnection';

/*
    In case of couple DB connections extend `cache`
*/
const cache: { instance: Repository} = {
    instance: null,
};

export type CreateRepositoryOptions = {
    mariadb: CreateMariaDbConnection;
    shared: boolean;
};

/**
 * @function
 * @param {Object} options - repository options
 * @param {Object} options.redis - redis connection
 * @param {Object} options.mariadb - mariadb pool connection
 * @return {Object} - DB API
 */
export function createRepository(options: CreateRepositoryOptions = { mariadb: null, shared: true }): Repository {
    let repository: Repository;
    let shared: boolean;

    shared = shared || true;

    if (shared) {
        repository = cache.instance;
        if (repository) {
            return repository;
        }
    }

    repository = new Repository(options);

    if (shared) {
        cache.instance = repository;
    }

    return repository;
}
