import * as mysql from 'mysql';

function QueryAsync(pool: mysql.Pool): (sqlStatement: string, params: string[]) => Promise<any> {
    return async function queryAsync(sqlStatement: string, params: string[]): Promise<any> {
        return new Promise((resolve: Function, reject: Function) => {
            if (!sqlStatement) {
                reject('WRONG_SQL_STATEMENT');
            }
            pool.getConnection(function (err: mysql.MysqlError, connection: mysql.PoolConnection): void {
                if (err) {
                    reject(err);
                }
                if (params) {
                    connection.query(sqlStatement, params, function (error: mysql.MysqlError, result: any): void {
                        connection.release();
                        if (error) {
                            reject(error);
                        }
                        resolve(result);
                    });
                } else {
                    connection.query(sqlStatement, function (error: mysql.MysqlError, result: any): void {
                        connection.release();
                        if (error) {
                            reject(error);
                        }
                        resolve(result);
                    });
                }
            });
        });
    };
}

type IQueryAsync = (sqlStatement: string, params: string[]) => Promise<any>;

export type CreateMariaDbConnection = {
    pool: mysql.Pool ;
    queryAsync: IQueryAsync;
};

/**
 * @function
 * @param {Object} options - database connection options
 * @param {String} options.host - database host name
 * @param {String} options.port - database port number
 * @param {String} options.user - database user
 * @param {String} options.database - database schema name
 * @param {String} options.password - database password
 * @param {Number} options.connectionsLimit - database user
 * @return {Object} - DB API
 */
export function createMariaDbConnection(options: mysql.PoolConfig): CreateMariaDbConnection {
    const pool: mysql.Pool = mysql.createPool({
        ...options,
        multipleStatements: true
    });
    return {
        pool,
        queryAsync: QueryAsync(pool),
    };
}
