import { SendMessageCommandInput, SendMessageResult, SQS } from '@aws-sdk/client-sqs';
import { AdaptiveRetryStrategy, DEFAULT_MAX_ATTEMPTS, RETRY_MODES } from '@aws-sdk/util-retry';
import config from '../../../config';

export const MAXIMUM_ATTEMPTS: number = 3;

export const adaptiveRetryStrategy: AdaptiveRetryStrategy = new AdaptiveRetryStrategy(
    () => Promise.resolve(MAXIMUM_ATTEMPTS)
);

export class SqsClient {
    private sqs: SQS;

    public constructor() {
        this.sqs = new SQS({
            region: config.sqs.region,
            retryStrategy: adaptiveRetryStrategy,
            retryMode: RETRY_MODES.STANDARD,
            maxAttempts: DEFAULT_MAX_ATTEMPTS,
        });
    }

    public send(message: any, queueUrls: string[]): void {
        const messageBody: string = JSON.stringify(message);

        queueUrls.forEach((queueUrl: string) => {
            const request: SendMessageCommandInput = {
                MessageBody: messageBody,
                // MessageBody: JSON.stringify({ ...message, ts: new Date().toISOString() }),
                QueueUrl: queueUrl,
            };
            this.sqs.sendMessage(request, function(err: any, data: SendMessageResult): void {
                if (err) { console.error('Error', err); }
                // else { console.log('Success', data.MessageId); }
            });
        });
    }
}
