import {
    IAnchorReboot,
    IBatteryLevel,
    ISiteDisconnected,
    ISqsAnchorReboot,
    ISqsBatteryLevel,
    ISqsSiteDisconnected,
    ISqsUnresponsiveNodeEvent,
    IUnresponsiveNode
} from './interfaces';

export async function createSqsUnresponsiveNodeEvent(
    message: IUnresponsiveNode,
    location_uid: string,
    sublocation_name: string,
    location_name: string,
    project_name: string,
    server_host: string
): Promise<ISqsUnresponsiveNodeEvent> {
    return {
        anchor_name: message.data.name,
        anchor_uid: message.subject_uid,
        location_name,
        location_uid,
        mac: message.data.mac,
        project_name,
        project_uid: message.project_uid,
        server_host,
        server_uid: message.server_uid,
        state: message.state,
        sublocation_name,
        sublocation_uid: message.sublocation_uid,
        timestamp: message.timestamp,
        type: message.type,
        uid: message.uid,
    };
}

export async function createSqsBatteryLevelEvent(
    message: IBatteryLevel,
    location_uid: string,
    sublocation_name: string,
    location_name: string,
    project_name: string,
    server_host: string,
): Promise<ISqsBatteryLevel> {
    return {
        location_name,
        location_uid,
        mac: message.data.mac,
        mv: message.data.mv,
        pr: message.data.pr,
        project_name,
        project_uid: message.project_uid,
        server_host,
        server_uid: message.server_uid,
        sublocation_name,
        sublocation_uid: message.sublocation_uid,
        timestamp: message.timestamp,
        trackable_name: message.data.name,
        trackable_uid: message.subject_uid,
        type: message.type,
        uid: message.uid,
    };
}

export async function createSqsAnchorRebootEvent(
    message: IAnchorReboot,
    location_uid: string,
    sublocation_name: string,
    location_name: string,
    project_name: string,
    server_host: string,
): Promise<ISqsAnchorReboot> {
    return {
        anchor_name: message.data.name,
        anchor_uid: message.subject_uid,
        location_name,
        location_uid,
        mac: message.data.mac,
        project_name,
        project_uid: message.project_uid,
        server_host,
        server_uid: message.server_uid,
        sublocation_name,
        sublocation_uid: message.sublocation_uid,
        timestamp: message.timestamp,
        type: message.type,
        uid: message.uid,
    };
}

export async function createSqsSiteDisconnectedEvent(
    message: ISiteDisconnected,
    location_uid: string,
    sublocation_name: string,
    location_name: string,
    project_name: string,
    server_host: string,
): Promise<ISqsSiteDisconnected> {
    return {
        location_name,
        location_uid,
        project_name,
        project_uid: message.project_uid,
        server_host,
        server_uid: message.server_uid,
        state: message.state,
        sublocation_name,
        sublocation_uid: message.sublocation_uid,
        timestamp: message.timestamp,
        type: message.type,
        uid: message.uid,
    };
}
