/**
 * See: https://redpointpositioning.atlassian.net/wiki/spaces/EN/pages/1951105109/Amazon+RTLS+Monitoring+Service#Site-Monitor-Events---SQS
 */
export interface ISqsUnresponsiveNodeEvent {
    anchor_name: string;
    anchor_uid: string;
    location_name: string;
    location_uid: string; // "2018-08-15T12:50:00.000Z",
    mac: string; // SET, CLEAR
    project_name: string;
    project_uid: string;
    server_host: string; // 45 chars
    server_uid: string;
    state: string; // 45 chars
    sublocation_name: string;
    sublocation_uid: string; // 45 chars
    timestamp: string;
    type: string;
    uid: string;
}

export interface ISqsSiteDisconnected {
    location_name: string;
    location_uid: string;
    project_name: string;
    project_uid: string;
    server_host: string;
    server_uid: string;
    state: string;
    sublocation_name: string;
    sublocation_uid: string;
    timestamp: string;
    type: string;
    uid: string;
}

export interface ISqsAnchorReboot {
    anchor_name: string;
    anchor_uid: string;
    location_name: string;
    location_uid: string;
    mac: string;
    project_name: string;
    project_uid: string;
    server_host: string;
    server_uid: string;
    sublocation_name: string;
    sublocation_uid: string;
    timestamp: string;
    type: string;
    uid: string;
}

export interface ISqsBatteryLevel {
    location_name: string;
    location_uid: string;
    mac: string;
    mv: number;
    pr: number;
    project_name: string;
    project_uid: string;
    server_host: string;
    server_uid: string;
    sublocation_name: string;
    sublocation_uid: string;
    timestamp: string;
    trackable_name: string;
    trackable_uid: string;
    type: string;
    uid: string;
}

export interface IBatteryLevel {
    company_uid: string;
    data: {
        fw: string;
        hw: string;
        mac: string;
        mv: number;
        name: string;
        pr: number;
        type: string
    };
    level: string;
    project_uid: string;
    server_uid: string;
    state: string;
    subject: string;
    subject_uid: string;
    sublocation_uid: string;
    timestamp: string;
    type: string;
    uid: string;
}

export interface IAnchorReboot {
    company_uid: string;
    data: {
        fw: string,
        hw: string,
        mac: string,
        name: string,
        type: string
    };
    level: string;
    project_uid: string;
    server_uid: string;
    state: string;
    subject: string;
    subject_uid: string;
    sublocation_uid: string;
    timestamp: string;
    type: string;
    uid: string;
}

export interface ISiteDisconnected {
    company_uid: string;
    data: {};
    level: string;
    project_uid: string;
    server_uid: string;
    state: string;
    subject: string;
    subject_uid: string;
    sublocation_uid: string;
    timestamp: string;
    type: string;
    uid: string;
}

export interface IUnresponsiveNode {
    company_uid: string;
    data: {
        fw: string,
        hw: string,
        mac: string,
        name: string,
        type: string,
    };
    level: string;
    project_uid: string;
    server_uid: string;
    state: string;
    subject: string;
    subject_uid: string;
    sublocation_uid: string;
    timestamp: string;
    type: string;
    uid: string;
}

export type SqsHandleEvents = IAnchorReboot | IBatteryLevel | ISiteDisconnected | IUnresponsiveNode;
