import UseCaseBase, { IExecuteResult } from '../UseCaseBase';
import { IBatteryLevel, ISqsBatteryLevel } from '../../models/interfaces';
import { createSqsBatteryLevelEvent } from '../../models/formatters';
import config from '../../../config';
import { ISublocationResponse, Location, Project, Server, Sublocation } from '../../models';

export class BatteryLevelHandler extends UseCaseBase {
    protected async execute(message: IBatteryLevel): Promise<IExecuteResult> {
        if (message.subject === 'TO') {
            const {location_uid, sublocation_name}: ISublocationResponse =
                await new Sublocation().getSublocationNameLocationUid(message.sublocation_uid);
            const location_name: string = await new Location().getLocationName(location_uid);
            const project_name: string = await new Project().getProjectName(message.server_uid + '_' + message.project_uid);
            const server_host: string = await new Server().getServerName(message.server_uid);

            const sqsMessage: ISqsBatteryLevel = await createSqsBatteryLevelEvent(
                message,
                location_uid,
                sublocation_name,
                location_name,
                project_name,
                server_host,
            );
            this.sqsClient.send(sqsMessage, config.queues.battery_level);
            return { messageBody: sqsMessage, queues: config.queues.battery_level };
        }
        return null;
    }
}
