import UseCaseBase, { IExecuteResult } from '../UseCaseBase';
import { ISiteDisconnected, ISqsSiteDisconnected } from '../../models/interfaces';
import { createSqsSiteDisconnectedEvent } from '../../models/formatters';
import config from '../../../config';
import { ISublocationResponse, Location, Project, Server, Sublocation } from '../../models';

export class SiteDisconnectedHandler extends UseCaseBase {
    protected async execute(message: ISiteDisconnected): Promise<IExecuteResult> {
        const {location_uid, sublocation_name}: ISublocationResponse =
            await new Sublocation().getSublocationNameLocationUid(message.sublocation_uid);
        const location_name: string = await new Location().getLocationName(location_uid);
        const project_name: string = await new Project().getProjectName(message.server_uid + '_' + message.project_uid);
        const server_host: string = await new Server().getServerName(message.server_uid);

        const sqsMessage: ISqsSiteDisconnected = await createSqsSiteDisconnectedEvent(
            message,
            location_uid,
            sublocation_name,
            location_name,
            project_name,
            server_host,
        );
        this.sqsClient.send(sqsMessage, config.queues.site_disconnected);
        return { messageBody: sqsMessage, queues: config.queues.site_disconnected };
    }
}
