import UseCaseBase, { IExecuteResult } from '../UseCaseBase';
import { ISqsUnresponsiveNodeEvent, IUnresponsiveNode } from '../../models/interfaces';
import { createSqsUnresponsiveNodeEvent } from '../../models/formatters';
import config from '../../../config';
import { ISublocationResponse, Location, Project, Server, Sublocation } from '../../models';

export class UnresponsiveNodeHandler extends UseCaseBase {
    protected async execute(message: IUnresponsiveNode): Promise<IExecuteResult> {
        const {location_uid, sublocation_name}: ISublocationResponse =
            await new Sublocation().getSublocationNameLocationUid(message.sublocation_uid);
        const location_name: string = await new Location().getLocationName(location_uid);
        const project_name: string = await new Project().getProjectName(message.server_uid + '_' + message.project_uid);
        const server_host: string = await new Server().getServerName(message.server_uid);

        const sqsMessage: ISqsUnresponsiveNodeEvent = await createSqsUnresponsiveNodeEvent(
            message,
            location_uid,
            sublocation_name,
            location_name,
            project_name,
            server_host
        );
        this.sqsClient.send(sqsMessage, config.queues.unresponsive_node);
        return { messageBody: sqsMessage, queues: config.queues.unresponsive_node };
    }
}
