#!/usr/bin/env bash
set -x #echo on

RPM_DESCRIPTION="Redpoint Positioning RTLS site monitor addon sqs sender"
RPM_MAINTAINER=help@redpointpositioning.com
RPP_VENDOR="Redpoint Positioning, Inc."

PROJECT_HOME=${WORKSPACE}

echo "build rtls-site-monitor-addon-sqs-sender"
npm install --prefix addons/sqsSender

PROJECT=rtls-site-monitor-addon-sqs-sender

export PATH=/usr/local/bin:/usr/local/rbenv/shims:$PATH

VERSION="$( addons/sqsSender/sys-services/rtls-get-version.sh )" # 2021.3.36
RELEASE="$( addons/sqsSender/sys-services/rtls-get-release.sh )" # 0
FILE="$( addons/sqsSender/sys-services/rtls-get-file-name.sh )" # rtls-site-monitor-addon-sqs-sender_2021.3.36-0_amd64.deb

echo "PROJECT_HOME:       ${PROJECT_HOME}"
echo "BUILDING ON BRANCH: ${BRANCH_NAME}"
echo "VERSION:            ${VERSION}"
echo "RELEASE:            ${RELEASE}"
echo "FILE:               ${FILE}"

rm -f "${PROJECT_HOME}"/*.deb
rm -f "${PROJECT_HOME}"/*.rpm
[ -d "${PROJECT_HOME}"/releases ] && rm -f "${PROJECT_HOME}"/releases/*

rm -rf "${PROJECT_HOME}"/server/node_modules/figlet/fonts/Patorjk\'s\ Cheese.flf
rm -rf "${PROJECT_HOME}"/server/node_modules/figlet/importable-fonts/Patorjk\'s\ Cheese.js

fpm -s dir -t deb -f \
	--description "${RPM_DESCRIPTION}" \
	--maintainer  "${RPM_MAINTAINER}" \
	--vendor "${RPP_VENDOR}" \
	--license "Proprietary" \
	--provides "${PROJECT}" \
	--exclude ".git" \
	--prefix /home/rtls/rtls-site-monitor/addons \
	--before-remove addons/sqsSender/sys-services/pre-uninstall.sh \
	--before-install addons/sqsSender/sys-services/pre-install.sh \
	--after-install addons/sqsSender/sys-services/post-install.sh \
	--before-upgrade addons/sqsSender/sys-services/pre-update.sh \
	--after-upgrade addons/sqsSender/sys-services/post-update.sh \
	--post-uninstall addons/sqsSender/sys-services/post-uninstall.sh \
	--depends "nodejs (>= 20.5.1)" \
	--depends "rtls-site-monitor >= 2023.1.145" \
	--depends "MariaDB-client >= 10.5.0" \
	--depends "MariaDB-server >= 10.5.0" \
	--deb-group rtls \
	--deb-user rtls \
	--name "${PROJECT}" \
	--version "${VERSION}" \
	--iteration "${RELEASE}" \
	--package "${PROJECT_HOME}" \
	"$(pwd)"/addons/sqsSender/=/sqsSender \
	"$(pwd)"/addons/sqsSender.ts=/sqsSender.ts \
